[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[elpa] master 5140127 046/184: ivy.el: Run ispell-comments-and-strings
From: |
Oleh Krehel |
Subject: |
[elpa] master 5140127 046/184: ivy.el: Run ispell-comments-and-strings |
Date: |
Wed, 16 Oct 2019 13:14:46 -0400 (EDT) |
branch: master
commit 5140127194f11137b99e375482866798ba32885f
Author: Oleh Krehel <address@hidden>
Commit: Oleh Krehel <address@hidden>
ivy.el: Run ispell-comments-and-strings
---
ivy.el | 16 ++++++++--------
1 file changed, 8 insertions(+), 8 deletions(-)
diff --git a/ivy.el b/ivy.el
index ccea8d2..5b41319 100644
--- a/ivy.el
+++ b/ivy.el
@@ -1815,7 +1815,7 @@ like.")
'((ivy--regex-ignore-order . ivy--highlight-ignore-order)
(ivy--regex-fuzzy . ivy--highlight-fuzzy)
(ivy--regex-plus . ivy--highlight-default))
- "An alist of highlighting functions for each regex buidler function.")
+ "An alist of highlighting functions for each regex builder function.")
(defcustom ivy-initial-inputs-alist
'((org-refile . "^")
@@ -1940,7 +1940,7 @@ a regular expression.
DEF is for compatibility with `completing-read'.
-UPDATE-FN is called each time the candidate list is redisplayed.
+UPDATE-FN is called each time the candidate list is re-displayed.
When SORT is non-nil, `ivy-sort-functions-alist' determines how
to sort candidates before displaying them.
@@ -2617,7 +2617,7 @@ When GREEDY is non-nil, join words in a greedy way."
"Split STR into text before and after ! delimiter.
Do not split if the delimiter is escaped as \\!.
-Assumes there is at most one unescaped delimiter and discards
+Assumes there is at most one un-escaped delimiter and discards
text after delimiter if it is empty. Modifies match data."
(unless (string= str "")
(let ((delim "\\(?:\\`\\|[^\\]\\)\\(!\\)"))
@@ -2625,7 +2625,7 @@ text after delimiter if it is empty. Modifies match
data."
;; Store "\!" as "!".
(replace-regexp-in-string "\\\\!" "!" split t t))
(if (string-match delim str)
;; Ignore everything past first unescaped ! rather than
;; crashing. We can't warn or error because the minibuffer
is
;; already active.
(let* ((i (match-beginning 1))
@@ -2639,7 +2639,7 @@ text after delimiter if it is empty. Modifies match
data."
(defun ivy--split-spaces (str)
"Split STR on spaces, unless they're preceded by \\.
-No unescaped spaces are left in the output. Any substring not
+No un-escaped spaces are left in the output. Any substring not
constituting a valid regexp is passed to `regexp-quote'."
(when str
(let ((i 0) ; End of last search.
@@ -2648,7 +2648,7 @@ constituting a valid regexp is passed to `regexp-quote'."
(while (string-match "\\(\\\\ \\)\\| +" str i)
(setq i (match-end 0))
(if (not (match-beginning 1))
- ;; Unescaped space(s).
+ ;; Un-escaped space(s).
(let ((delim (match-beginning 0)))
(when (< j delim)
(push (substring str j delim) parts))
@@ -3954,7 +3954,7 @@ TREE can be nested multiple times to have multiple window
splits.")
When ARG is non-nil, replace a selected item on `ivy-views'.
-Currently, the split configuration (i.e. horizonal or vertical)
+Currently, the split configuration (i.e. horizontal or vertical)
and point positions are saved, but the split positions aren't.
Use `ivy-pop-view' to delete any item from `ivy-views'."
(interactive "P")
@@ -4663,7 +4663,7 @@ There is no limit on the number of *ivy-occur* buffers."
"Refresh the buffer making it up-to date with the collection.
Currently only works for `swiper'. In that specific case, the
-*ivy-occur* buffer becomes nearly useless as the orignal buffer
+*ivy-occur* buffer becomes nearly useless as the original buffer
is updated, since the line numbers no longer match.
Calling this function is as if you called `ivy-occur' on the
- [elpa] master 38b5d83 015/184: swiper.el (swiper--isearch-filter-ignore-order): Extract, (continued)
- [elpa] master 38b5d83 015/184: swiper.el (swiper--isearch-filter-ignore-order): Extract, Oleh Krehel, 2019/10/16
- [elpa] master 5f99723 019/184: counsel.el (counsel--async-last-command): Add for ease of debugging, Oleh Krehel, 2019/10/16
- [elpa] master fb486d8 024/184: ivy.el (ivy-immediate-done): Add copy-sequence to fix read-directory-name, Oleh Krehel, 2019/10/16
- [elpa] master f71f89a 029/184: ivy-test.el (ivy-swiper-wgrep): Expect fail on <=24.3, Oleh Krehel, 2019/10/16
- [elpa] master 230137b 047/184: ivy.el (ivy-restrict-to-matches): Work for dynamic collection, Oleh Krehel, 2019/10/16
- [elpa] master c3bd60c 041/184: ivy.el (ivy--occur-press-update-window): Don't error if buffer was killed, Oleh Krehel, 2019/10/16
- [elpa] master 6bf2cba 053/184: ivy.el (ivy-read-action-ivy): Don't recur, Oleh Krehel, 2019/10/16
- [elpa] master 1a4ebda 048/184: Allow virtual-buffers customization, Oleh Krehel, 2019/10/16
- [elpa] master b4af1a6 040/184: swiper.el (swiper-recenter-top-bottom): Works for swiper-isearch, Oleh Krehel, 2019/10/16
- [elpa] master 327dbd6 058/184: counsel.el (counsel-rg-base-command): Don't include directory on non-Windows, Oleh Krehel, 2019/10/16
- [elpa] master 5140127 046/184: ivy.el: Run ispell-comments-and-strings,
Oleh Krehel <=
- [elpa] master 2ecbd7d 054/184: ivy.el (ivy-read-action-ivy): Show the selected item in the prompt, Oleh Krehel, 2019/10/16
- [elpa] master ae70443 060/184: counsel.el (counsel-major): Add, Oleh Krehel, 2019/10/16
- [elpa] master f66eec5 059/184: Add counsel-buffer-or-recentf, Oleh Krehel, 2019/10/16
- [elpa] master 1303e10 061/184: counsel.el (counsel-M-x-action): Extract, Oleh Krehel, 2019/10/16
- [elpa] master ca5040d 078/184: counsel.el (counsel-rg-base-command): Remove "-S" flag, Oleh Krehel, 2019/10/16
- [elpa] master 20d604c 069/184: ivy.el (ivy-restrict-to-matches): Fix for ivy-resume, Oleh Krehel, 2019/10/16
- [elpa] master c307ae9 055/184: swiper.el (swiper--re-builder): Fix symbol bounds with char-fold-to-regexp, Oleh Krehel, 2019/10/16
- [elpa] master 5424a564 082/184: ivy.el (ivy--handle-directory): Extract, Oleh Krehel, 2019/10/16
- [elpa] master d73376f 010/184: ivy.el (ivy--trim-trailing-re): Add, Oleh Krehel, 2019/10/16
- [elpa] master 824f8d7 072/184: counsel.el (counsel--find-return-list): Works with or without "./" prefix, Oleh Krehel, 2019/10/16
@@ -2625,7 +2625,7 @@ text after delimiter if it is empty. Modifies match
(replace-regexp-in-string "\\\\!" "!" split t t))
(if (string-match delim str)
- ;; Ignore everything past first unescaped ! rather than
+ ;; Ignore everything past first un-escaped ! rather than
;; crashing. We can't warn or error because the minibuffer
is